## Brought to you by:
[![Quantum Leaps](https://www.state-machine.com/attachments/logo_ql_400.png)](https://www.state-machine.com)
<hr>

[![GitHub release (latest by date)](https://img.shields.io/github/v/release/QuantumLeaps/spexygen)](https://github.com/QuantumLeaps/spexygen/releases/latest)
[![GitHub](https://img.shields.io/github/license/QuantumLeaps/spexygen)](https://github.com/QuantumLeaps/spexygen/blob/main/LICENSE)

<p align="center">
<a href="https://www.state-machine.com/spexygen">
<img src="https://www.state-machine.com/spexygen/banner_spexygen.webp"/></a>
</p>

# Spexygen - Traceable Specifications Based on Doxygen
_Spexygen_ documentation (generated with _Spexygen_) is available at:
- [Spexygen Reference Manual in HTML](https://www.state-machine.com/spexygen)
- [Spexygen Reference Manual in PDF](https://www.state-machine.com/spexygen/DOC_MAN_SPX.pdf)

<p align="center">
<a href="https://youtu.be/5naC_z-76Aw?si=x4Svroqv9qDdkpsE" target="_blank" title="Spexygen video">
<img src="https://www.state-machine.com/attachments/spexygen-video.jpg"><br>
Traceable Documentation with Doxygen &amp; Spexygen</a>
</p>

# Licensing
Spexygen is released under the terms of the permissive [MIT open source license](LICENSE).
Please note that the attribution clause in the MIT license requires you to preserve
the original copyright notice in all changes and derivate works.

# How to Help this Project?
Please feel free to clone, fork, and make pull requests to improve **Spexygen**.
If you like this project, please give it a star on GitHub (in the upper-right corner
of your browser window):

<p align="center">
<img src="https://www.state-machine.com/attachments/github-star.jpg"/>
</p>
